Lab4-package: Linear Regression

Description Details Author(s)

Description

This package is created to handle linear regression models.

Details

The DESCRIPTION file: This package was not yet installed at build time.

Index: This package was not yet installed at build time.

Author(s)

Pedram , Mariano and Roshni

Maintainer: <pedka102@student.liu.se>


pedism/Lab4 documentation built on May 14, 2019, 12:10 p.m.