lab4-package: Linear Regression

Description Details Author(s) Examples

Description

this package includes multiple function of plot, print, summary etc

Details

The DESCRIPTION file: This package was not yet installed at build time.

Index: This package was not yet installed at build time.
~~ this package is calculating the linear regression on the dataset provided and the fomula passed to the class. package is using RC class implementation for linear Regression. there are various function which are overloaded like print, summary, plot, coef, pred and resid. ~~

Author(s)

Mahmood Siddique

Maintainer: Who to complain to <mahmood1s@gmail.com>

Examples

1
2
3
4
5
6
7
8
9
## Not run: 
mat_obj<-linreg$new(Petal.Length~Sepal.Width+Sepal.Length,data = iris)
mat_obj$print()
mat_obj$plot()
mat_obj$pred()
mat_obj$resid()
mat_obj$summary()

## End(Not run)

Mahmood1s/lab4 documentation built on Oct. 30, 2019, 9:09 p.m.