linreg-class: this class is calculating Regressions coefficients, fitted...

Description Arguments Value Examples

Description

this class is calculating Regressions coefficients, fitted values, residuals, degrees of freedom, residual variance, variance of the regression coefficients, t-values for each coefficient and p-value for each coefficient.

Arguments

formula

this is the formula that need to be passed into contructor of the class, it will contain variable names from data frame.

data

this will be the data frame that we are working on.

Value

this will return class object, which will then be used to access multiple function of the class.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
## Not run: 
data("iris")
mat_obj<-linreg$new()
mat_obj<-mat_obj$linreg(formula=Petal.Length~Species,data = iris)
mat_obj$print()
mat_obj$plot()
mat_obj$resid()
mat_obj$summary()

## End(Not run)

Mahmood1s/lab4 documentation built on Oct. 30, 2019, 9:09 p.m.