This package is created to handle linear regression models.
The DESCRIPTION file:
This package was not yet installed at build time.
Index: This package was not yet installed at build time.
Pedram , Mariano and Roshni
Maintainer: <pedka102@student.liu.se>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.