Description Details Author(s) Examples
this package includes multiple function of plot, print, summary etc
The DESCRIPTION file:
This package was not yet installed at build time.
Index: This package was not yet installed at build time.
~~ this package is calculating the linear regression on the dataset provided and the fomula passed to the class. package is using RC class implementation for linear Regression. there are various function which are overloaded like print, summary, plot, coef, pred and resid. ~~
Mahmood Siddique
Maintainer: Who to complain to <mahmood1s@gmail.com>
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.