Description Arguments Value Examples
this class is calculating Regressions coefficients, fitted values, residuals, degrees of freedom, residual variance, variance of the regression coefficients, t-values for each coefficient and p-value for each coefficient.
formula |
this is the formula that need to be passed into contructor of the class, it will contain variable names from data frame. |
data |
this will be the data frame that we are working on. |
this will return class object, which will then be used to access multiple function of the class.
1 2 3 4 5 6 7 8 9 10 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.