A class for linear regression with many methods for corresponding values calculations
yvector The orginial labels of observations in data
Xmatrix The features of all observations in data
betavector The coefficients in the sample
y_hatmatrix The estimated labels
e_hatmatrix The standard errors between orginial and estimated labels
dfnumeric The degree of freedom of data
var_residnumeric The residual variance
var_hatmatrix The variance of the regression coefficients
t_valvector The t-values for each coefficient
p_valvector The p-values for each coefficient
formulacharacter The formula used in the model
datadata.frame The sample data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.